Class: KoronaCloudClient::AccountMaxRevisions

Inherits:
Object
  • Object
show all
Defined in:
lib/korona-cloud-client/models/account_max_revisions.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AccountMaxRevisions

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 347

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KoronaCloudClient::AccountMaxRevisions` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KoronaCloudClient::AccountMaxRevisions`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'additional_receipt_info_type')
    self.additional_receipt_info_type = attributes[:'additional_receipt_info_type']
  end

  if attributes.key?(:'assortment')
    self.assortment = attributes[:'assortment']
  end

  if attributes.key?(:'attendance')
    self.attendance = attributes[:'attendance']
  end

  if attributes.key?(:'cashier')
    self.cashier = attributes[:'cashier']
  end

  if attributes.key?(:'cashier_role')
    self.cashier_role = attributes[:'cashier_role']
  end

  if attributes.key?(:'cashier_verification_requirement')
    self.cashier_verification_requirement = attributes[:'cashier_verification_requirement']
  end

  if attributes.key?(:'commodity_group')
    self.commodity_group = attributes[:'commodity_group']
  end

  if attributes.key?(:'contra_account')
    self. = attributes[:'contra_account']
  end

  if attributes.key?(:'cost_center')
    self.cost_center = attributes[:'cost_center']
  end

  if attributes.key?(:'coupon')
    self.coupon = attributes[:'coupon']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'customer')
    self.customer = attributes[:'customer']
  end

  if attributes.key?(:'customer_display_configuration')
    self.customer_display_configuration = attributes[:'customer_display_configuration']
  end

  if attributes.key?(:'customer_group')
    self.customer_group = attributes[:'customer_group']
  end

  if attributes.key?(:'customer_order')
    self.customer_order = attributes[:'customer_order']
  end

  if attributes.key?(:'data_exchange_configuration')
    self.data_exchange_configuration = attributes[:'data_exchange_configuration']
  end

  if attributes.key?(:'delivery_note')
    self.delivery_note = attributes[:'delivery_note']
  end

  if attributes.key?(:'device_configuration_variable')
    self.device_configuration_variable = attributes[:'device_configuration_variable']
  end

  if attributes.key?(:'discount_configuration')
    self.discount_configuration = attributes[:'discount_configuration']
  end

  if attributes.key?(:'discount_level')
    self.discount_level = attributes[:'discount_level']
  end

  if attributes.key?(:'dispatch_notification')
    self.dispatch_notification = attributes[:'dispatch_notification']
  end

  if attributes.key?(:'dispatch_notification_item')
    self.dispatch_notification_item = attributes[:'dispatch_notification_item']
  end

  if attributes.key?(:'economic_zone')
    self.economic_zone = attributes[:'economic_zone']
  end

  if attributes.key?(:'end_of_day_statement')
    self.end_of_day_statement = attributes[:'end_of_day_statement']
  end

  if attributes.key?(:'entry_gate')
    self.entry_gate = attributes[:'entry_gate']
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'external_system_call')
    self.external_system_call = attributes[:'external_system_call']
  end

  if attributes.key?(:'fiscal_unit')
    self.fiscal_unit = attributes[:'fiscal_unit']
  end

  if attributes.key?(:'image')
    self.image = attributes[:'image']
  end

  if attributes.key?(:'info_text')
    self.info_text = attributes[:'info_text']
  end

  if attributes.key?(:'inventory')
    self.inventory = attributes[:'inventory']
  end

  if attributes.key?(:'inventory_list')
    self.inventory_list = attributes[:'inventory_list']
  end

  if attributes.key?(:'inventory_list_item')
    self.inventory_list_item = attributes[:'inventory_list_item']
  end

  if attributes.key?(:'item_sequence')
    self.item_sequence = attributes[:'item_sequence']
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end

  if attributes.key?(:'loyalty_card')
    self.loyalty_card = attributes[:'loyalty_card']
  end

  if attributes.key?(:'number_range_configuration')
    self.number_range_configuration = attributes[:'number_range_configuration']
  end

  if attributes.key?(:'order_portal_supplier')
    self.order_portal_supplier = attributes[:'order_portal_supplier']
  end

  if attributes.key?(:'organizational_unit')
    self.organizational_unit = attributes[:'organizational_unit']
  end

  if attributes.key?(:'payment_method')
    self.payment_method = attributes[:'payment_method']
  end

  if attributes.key?(:'payment_method_category')
    self.payment_method_category = attributes[:'payment_method_category']
  end

  if attributes.key?(:'pos')
    self.pos = attributes[:'pos']
  end

  if attributes.key?(:'pos_balance')
    self.pos_balance = attributes[:'pos_balance']
  end

  if attributes.key?(:'pos_button_layout')
    self.pos_button_layout = attributes[:'pos_button_layout']
  end

  if attributes.key?(:'pos_page_layout_configuration')
    self.pos_page_layout_configuration = attributes[:'pos_page_layout_configuration']
  end

  if attributes.key?(:'pos_profile')
    self.pos_profile = attributes[:'pos_profile']
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'price_group')
    self.price_group = attributes[:'price_group']
  end

  if attributes.key?(:'price_rule')
    self.price_rule = attributes[:'price_rule']
  end

  if attributes.key?(:'product')
    self.product = attributes[:'product']
  end

  if attributes.key?(:'production_type')
    self.production_type = attributes[:'production_type']
  end

  if attributes.key?(:'promotion')
    self.promotion = attributes[:'promotion']
  end

  if attributes.key?(:'receipt')
    self.receipt = attributes[:'receipt']
  end

  if attributes.key?(:'receipt_layout_configuration')
    self.receipt_layout_configuration = attributes[:'receipt_layout_configuration']
  end

  if attributes.key?(:'report_file')
    self.report_file = attributes[:'report_file']
  end

  if attributes.key?(:'revenue_account')
    self. = attributes[:'revenue_account']
  end

  if attributes.key?(:'sales_tax')
    self.sales_tax = attributes[:'sales_tax']
  end

  if attributes.key?(:'sector')
    self.sector = attributes[:'sector']
  end

  if attributes.key?(:'special_price_configuration')
    self.special_price_configuration = attributes[:'special_price_configuration']
  end

  if attributes.key?(:'stock_adjustment')
    self.stock_adjustment = attributes[:'stock_adjustment']
  end

  if attributes.key?(:'stock_adjustment_item')
    self.stock_adjustment_item = attributes[:'stock_adjustment_item']
  end

  if attributes.key?(:'stock_order')
    self.stock_order = attributes[:'stock_order']
  end

  if attributes.key?(:'stock_order_item')
    self.stock_order_item = attributes[:'stock_order_item']
  end

  if attributes.key?(:'stock_receipt')
    self.stock_receipt = attributes[:'stock_receipt']
  end

  if attributes.key?(:'stock_receipt_item')
    self.stock_receipt_item = attributes[:'stock_receipt_item']
  end

  if attributes.key?(:'supplier')
    self.supplier = attributes[:'supplier']
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end

  if attributes.key?(:'ticket_definition')
    self.ticket_definition = attributes[:'ticket_definition']
  end

  if attributes.key?(:'time_tracking_entity')
    self.time_tracking_entity = attributes[:'time_tracking_entity']
  end

  if attributes.key?(:'time_tracking_entry')
    self.time_tracking_entry = attributes[:'time_tracking_entry']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'user_role')
    self.user_role = attributes[:'user_role']
  end

  if attributes.key?(:'voucher')
    self.voucher = attributes[:'voucher']
  end

  if attributes.key?(:'voucher_configuration')
    self.voucher_configuration = attributes[:'voucher_configuration']
  end

  if attributes.key?(:'voucher_transaction')
    self.voucher_transaction = attributes[:'voucher_transaction']
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



18
19
20
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 18

def 
  @account
end

#additional_receipt_info_typeObject

Returns the value of attribute additional_receipt_info_type.



20
21
22
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 20

def additional_receipt_info_type
  @additional_receipt_info_type
end

#assortmentObject

Returns the value of attribute assortment.



22
23
24
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 22

def assortment
  @assortment
end

#attendanceObject

Returns the value of attribute attendance.



24
25
26
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 24

def attendance
  @attendance
end

#cashierObject

Returns the value of attribute cashier.



26
27
28
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 26

def cashier
  @cashier
end

#cashier_roleObject

Returns the value of attribute cashier_role.



28
29
30
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 28

def cashier_role
  @cashier_role
end

#cashier_verification_requirementObject

Returns the value of attribute cashier_verification_requirement.



30
31
32
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 30

def cashier_verification_requirement
  @cashier_verification_requirement
end

#commodity_groupObject

Returns the value of attribute commodity_group.



32
33
34
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 32

def commodity_group
  @commodity_group
end

#contra_accountObject

Returns the value of attribute contra_account.



34
35
36
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 34

def 
  @contra_account
end

#cost_centerObject

Returns the value of attribute cost_center.



36
37
38
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 36

def cost_center
  @cost_center
end

#couponObject

Returns the value of attribute coupon.



38
39
40
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 38

def coupon
  @coupon
end

#currencyObject

Returns the value of attribute currency.



40
41
42
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 40

def currency
  @currency
end

#customerObject

Returns the value of attribute customer.



42
43
44
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 42

def customer
  @customer
end

#customer_display_configurationObject

Returns the value of attribute customer_display_configuration.



44
45
46
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 44

def customer_display_configuration
  @customer_display_configuration
end

#customer_groupObject

Returns the value of attribute customer_group.



46
47
48
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 46

def customer_group
  @customer_group
end

#customer_orderObject

Returns the value of attribute customer_order.



48
49
50
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 48

def customer_order
  @customer_order
end

#data_exchange_configurationObject

Returns the value of attribute data_exchange_configuration.



50
51
52
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 50

def data_exchange_configuration
  @data_exchange_configuration
end

#delivery_noteObject

Returns the value of attribute delivery_note.



52
53
54
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 52

def delivery_note
  @delivery_note
end

#device_configuration_variableObject

Returns the value of attribute device_configuration_variable.



54
55
56
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 54

def device_configuration_variable
  @device_configuration_variable
end

#discount_configurationObject

Returns the value of attribute discount_configuration.



56
57
58
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 56

def discount_configuration
  @discount_configuration
end

#discount_levelObject

Returns the value of attribute discount_level.



58
59
60
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 58

def discount_level
  @discount_level
end

#dispatch_notificationObject

Returns the value of attribute dispatch_notification.



60
61
62
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 60

def dispatch_notification
  @dispatch_notification
end

#dispatch_notification_itemObject

Returns the value of attribute dispatch_notification_item.



62
63
64
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 62

def dispatch_notification_item
  @dispatch_notification_item
end

#economic_zoneObject

Returns the value of attribute economic_zone.



64
65
66
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 64

def economic_zone
  @economic_zone
end

#end_of_day_statementObject

Returns the value of attribute end_of_day_statement.



66
67
68
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 66

def end_of_day_statement
  @end_of_day_statement
end

#entry_gateObject

Returns the value of attribute entry_gate.



68
69
70
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 68

def entry_gate
  @entry_gate
end

#eventObject

Returns the value of attribute event.



70
71
72
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 70

def event
  @event
end

#external_system_callObject

Returns the value of attribute external_system_call.



72
73
74
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 72

def external_system_call
  @external_system_call
end

#fiscal_unitObject

Returns the value of attribute fiscal_unit.



74
75
76
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 74

def fiscal_unit
  @fiscal_unit
end

#imageObject

Returns the value of attribute image.



76
77
78
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 76

def image
  @image
end

#info_textObject

Returns the value of attribute info_text.



78
79
80
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 78

def info_text
  @info_text
end

#inventoryObject

Returns the value of attribute inventory.



80
81
82
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 80

def inventory
  @inventory
end

#inventory_listObject

Returns the value of attribute inventory_list.



82
83
84
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 82

def inventory_list
  @inventory_list
end

#inventory_list_itemObject

Returns the value of attribute inventory_list_item.



84
85
86
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 84

def inventory_list_item
  @inventory_list_item
end

#item_sequenceObject

Returns the value of attribute item_sequence.



86
87
88
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 86

def item_sequence
  @item_sequence
end

#languageObject

Returns the value of attribute language.



88
89
90
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 88

def language
  @language
end

#loyalty_cardObject

Returns the value of attribute loyalty_card.



90
91
92
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 90

def loyalty_card
  @loyalty_card
end

#number_range_configurationObject

Returns the value of attribute number_range_configuration.



92
93
94
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 92

def number_range_configuration
  @number_range_configuration
end

#order_portal_supplierObject

Returns the value of attribute order_portal_supplier.



94
95
96
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 94

def order_portal_supplier
  @order_portal_supplier
end

#organizational_unitObject

Returns the value of attribute organizational_unit.



96
97
98
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 96

def organizational_unit
  @organizational_unit
end

#payment_methodObject

Returns the value of attribute payment_method.



98
99
100
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 98

def payment_method
  @payment_method
end

#payment_method_categoryObject

Returns the value of attribute payment_method_category.



100
101
102
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 100

def payment_method_category
  @payment_method_category
end

#posObject

Returns the value of attribute pos.



102
103
104
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 102

def pos
  @pos
end

#pos_balanceObject

Returns the value of attribute pos_balance.



104
105
106
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 104

def pos_balance
  @pos_balance
end

#pos_button_layoutObject

Returns the value of attribute pos_button_layout.



106
107
108
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 106

def pos_button_layout
  @pos_button_layout
end

#pos_page_layout_configurationObject

Returns the value of attribute pos_page_layout_configuration.



108
109
110
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 108

def pos_page_layout_configuration
  @pos_page_layout_configuration
end

#pos_profileObject

Returns the value of attribute pos_profile.



110
111
112
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 110

def pos_profile
  @pos_profile
end

#priceObject

Returns the value of attribute price.



112
113
114
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 112

def price
  @price
end

#price_groupObject

Returns the value of attribute price_group.



114
115
116
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 114

def price_group
  @price_group
end

#price_ruleObject

Returns the value of attribute price_rule.



116
117
118
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 116

def price_rule
  @price_rule
end

#productObject

Returns the value of attribute product.



118
119
120
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 118

def product
  @product
end

#production_typeObject

Returns the value of attribute production_type.



120
121
122
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 120

def production_type
  @production_type
end

#promotionObject

Returns the value of attribute promotion.



122
123
124
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 122

def promotion
  @promotion
end

#receiptObject

Returns the value of attribute receipt.



124
125
126
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 124

def receipt
  @receipt
end

#receipt_layout_configurationObject

Returns the value of attribute receipt_layout_configuration.



126
127
128
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 126

def receipt_layout_configuration
  @receipt_layout_configuration
end

#report_fileObject

Returns the value of attribute report_file.



128
129
130
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 128

def report_file
  @report_file
end

#revenue_accountObject

Returns the value of attribute revenue_account.



130
131
132
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 130

def 
  @revenue_account
end

#sales_taxObject

Returns the value of attribute sales_tax.



132
133
134
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 132

def sales_tax
  @sales_tax
end

#sectorObject

Returns the value of attribute sector.



134
135
136
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 134

def sector
  @sector
end

#special_price_configurationObject

Returns the value of attribute special_price_configuration.



136
137
138
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 136

def special_price_configuration
  @special_price_configuration
end

#stock_adjustmentObject

Returns the value of attribute stock_adjustment.



138
139
140
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 138

def stock_adjustment
  @stock_adjustment
end

#stock_adjustment_itemObject

Returns the value of attribute stock_adjustment_item.



140
141
142
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 140

def stock_adjustment_item
  @stock_adjustment_item
end

#stock_orderObject

Returns the value of attribute stock_order.



142
143
144
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 142

def stock_order
  @stock_order
end

#stock_order_itemObject

Returns the value of attribute stock_order_item.



144
145
146
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 144

def stock_order_item
  @stock_order_item
end

#stock_receiptObject

Returns the value of attribute stock_receipt.



146
147
148
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 146

def stock_receipt
  @stock_receipt
end

#stock_receipt_itemObject

Returns the value of attribute stock_receipt_item.



148
149
150
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 148

def stock_receipt_item
  @stock_receipt_item
end

#supplierObject

Returns the value of attribute supplier.



150
151
152
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 150

def supplier
  @supplier
end

#tagObject

Returns the value of attribute tag.



152
153
154
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 152

def tag
  @tag
end

#ticket_definitionObject

Returns the value of attribute ticket_definition.



154
155
156
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 154

def ticket_definition
  @ticket_definition
end

#time_tracking_entityObject

Returns the value of attribute time_tracking_entity.



156
157
158
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 156

def time_tracking_entity
  @time_tracking_entity
end

#time_tracking_entryObject

Returns the value of attribute time_tracking_entry.



158
159
160
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 158

def time_tracking_entry
  @time_tracking_entry
end

#userObject

Returns the value of attribute user.



160
161
162
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 160

def user
  @user
end

#user_roleObject

Returns the value of attribute user_role.



162
163
164
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 162

def user_role
  @user_role
end

#voucherObject

Returns the value of attribute voucher.



164
165
166
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 164

def voucher
  @voucher
end

#voucher_configurationObject

Returns the value of attribute voucher_configuration.



166
167
168
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 166

def voucher_configuration
  @voucher_configuration
end

#voucher_transactionObject

Returns the value of attribute voucher_transaction.



168
169
170
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 168

def voucher_transaction
  @voucher_transaction
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 802

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KoronaCloudClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



253
254
255
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 253

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 171

def self.attribute_map
  {
    :'account' => :'account',
    :'additional_receipt_info_type' => :'additionalReceiptInfoType',
    :'assortment' => :'assortment',
    :'attendance' => :'attendance',
    :'cashier' => :'cashier',
    :'cashier_role' => :'cashierRole',
    :'cashier_verification_requirement' => :'cashierVerificationRequirement',
    :'commodity_group' => :'commodityGroup',
    :'contra_account' => :'contraAccount',
    :'cost_center' => :'costCenter',
    :'coupon' => :'coupon',
    :'currency' => :'currency',
    :'customer' => :'customer',
    :'customer_display_configuration' => :'customerDisplayConfiguration',
    :'customer_group' => :'customerGroup',
    :'customer_order' => :'customerOrder',
    :'data_exchange_configuration' => :'dataExchangeConfiguration',
    :'delivery_note' => :'deliveryNote',
    :'device_configuration_variable' => :'deviceConfigurationVariable',
    :'discount_configuration' => :'discountConfiguration',
    :'discount_level' => :'discountLevel',
    :'dispatch_notification' => :'dispatchNotification',
    :'dispatch_notification_item' => :'dispatchNotificationItem',
    :'economic_zone' => :'economicZone',
    :'end_of_day_statement' => :'endOfDayStatement',
    :'entry_gate' => :'entryGate',
    :'event' => :'event',
    :'external_system_call' => :'externalSystemCall',
    :'fiscal_unit' => :'fiscalUnit',
    :'image' => :'image',
    :'info_text' => :'infoText',
    :'inventory' => :'inventory',
    :'inventory_list' => :'inventoryList',
    :'inventory_list_item' => :'inventoryListItem',
    :'item_sequence' => :'itemSequence',
    :'language' => :'language',
    :'loyalty_card' => :'loyaltyCard',
    :'number_range_configuration' => :'numberRangeConfiguration',
    :'order_portal_supplier' => :'orderPortalSupplier',
    :'organizational_unit' => :'organizationalUnit',
    :'payment_method' => :'paymentMethod',
    :'payment_method_category' => :'paymentMethodCategory',
    :'pos' => :'pos',
    :'pos_balance' => :'posBalance',
    :'pos_button_layout' => :'posButtonLayout',
    :'pos_page_layout_configuration' => :'posPageLayoutConfiguration',
    :'pos_profile' => :'posProfile',
    :'price' => :'price',
    :'price_group' => :'priceGroup',
    :'price_rule' => :'priceRule',
    :'product' => :'product',
    :'production_type' => :'productionType',
    :'promotion' => :'promotion',
    :'receipt' => :'receipt',
    :'receipt_layout_configuration' => :'receiptLayoutConfiguration',
    :'report_file' => :'reportFile',
    :'revenue_account' => :'revenueAccount',
    :'sales_tax' => :'salesTax',
    :'sector' => :'sector',
    :'special_price_configuration' => :'specialPriceConfiguration',
    :'stock_adjustment' => :'stockAdjustment',
    :'stock_adjustment_item' => :'stockAdjustmentItem',
    :'stock_order' => :'stockOrder',
    :'stock_order_item' => :'stockOrderItem',
    :'stock_receipt' => :'stockReceipt',
    :'stock_receipt_item' => :'stockReceiptItem',
    :'supplier' => :'supplier',
    :'tag' => :'tag',
    :'ticket_definition' => :'ticketDefinition',
    :'time_tracking_entity' => :'timeTrackingEntity',
    :'time_tracking_entry' => :'timeTrackingEntry',
    :'user' => :'user',
    :'user_role' => :'userRole',
    :'voucher' => :'voucher',
    :'voucher_configuration' => :'voucherConfiguration',
    :'voucher_transaction' => :'voucherTransaction'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 778

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



340
341
342
343
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 340

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 258

def self.openapi_types
  {
    :'account' => :'Integer',
    :'additional_receipt_info_type' => :'Integer',
    :'assortment' => :'Integer',
    :'attendance' => :'Integer',
    :'cashier' => :'Integer',
    :'cashier_role' => :'Integer',
    :'cashier_verification_requirement' => :'Integer',
    :'commodity_group' => :'Integer',
    :'contra_account' => :'Integer',
    :'cost_center' => :'Integer',
    :'coupon' => :'Integer',
    :'currency' => :'Integer',
    :'customer' => :'Integer',
    :'customer_display_configuration' => :'Integer',
    :'customer_group' => :'Integer',
    :'customer_order' => :'Integer',
    :'data_exchange_configuration' => :'Integer',
    :'delivery_note' => :'Integer',
    :'device_configuration_variable' => :'Integer',
    :'discount_configuration' => :'Integer',
    :'discount_level' => :'Integer',
    :'dispatch_notification' => :'Integer',
    :'dispatch_notification_item' => :'Integer',
    :'economic_zone' => :'Integer',
    :'end_of_day_statement' => :'Integer',
    :'entry_gate' => :'Integer',
    :'event' => :'Integer',
    :'external_system_call' => :'Integer',
    :'fiscal_unit' => :'Integer',
    :'image' => :'Integer',
    :'info_text' => :'Integer',
    :'inventory' => :'Integer',
    :'inventory_list' => :'Integer',
    :'inventory_list_item' => :'Integer',
    :'item_sequence' => :'Integer',
    :'language' => :'Integer',
    :'loyalty_card' => :'Integer',
    :'number_range_configuration' => :'Integer',
    :'order_portal_supplier' => :'Integer',
    :'organizational_unit' => :'Integer',
    :'payment_method' => :'Integer',
    :'payment_method_category' => :'Integer',
    :'pos' => :'Integer',
    :'pos_balance' => :'Integer',
    :'pos_button_layout' => :'Integer',
    :'pos_page_layout_configuration' => :'Integer',
    :'pos_profile' => :'Integer',
    :'price' => :'Integer',
    :'price_group' => :'Integer',
    :'price_rule' => :'Integer',
    :'product' => :'Integer',
    :'production_type' => :'Integer',
    :'promotion' => :'Integer',
    :'receipt' => :'Integer',
    :'receipt_layout_configuration' => :'Integer',
    :'report_file' => :'Integer',
    :'revenue_account' => :'Integer',
    :'sales_tax' => :'Integer',
    :'sector' => :'Integer',
    :'special_price_configuration' => :'Integer',
    :'stock_adjustment' => :'Integer',
    :'stock_adjustment_item' => :'Integer',
    :'stock_order' => :'Integer',
    :'stock_order_item' => :'Integer',
    :'stock_receipt' => :'Integer',
    :'stock_receipt_item' => :'Integer',
    :'supplier' => :'Integer',
    :'tag' => :'Integer',
    :'ticket_definition' => :'Integer',
    :'time_tracking_entity' => :'Integer',
    :'time_tracking_entry' => :'Integer',
    :'user' => :'Integer',
    :'user_role' => :'Integer',
    :'voucher' => :'Integer',
    :'voucher_configuration' => :'Integer',
    :'voucher_transaction' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 682

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      additional_receipt_info_type == o.additional_receipt_info_type &&
      assortment == o.assortment &&
      attendance == o.attendance &&
      cashier == o.cashier &&
      cashier_role == o.cashier_role &&
      cashier_verification_requirement == o.cashier_verification_requirement &&
      commodity_group == o.commodity_group &&
       == o. &&
      cost_center == o.cost_center &&
      coupon == o.coupon &&
      currency == o.currency &&
      customer == o.customer &&
      customer_display_configuration == o.customer_display_configuration &&
      customer_group == o.customer_group &&
      customer_order == o.customer_order &&
      data_exchange_configuration == o.data_exchange_configuration &&
      delivery_note == o.delivery_note &&
      device_configuration_variable == o.device_configuration_variable &&
      discount_configuration == o.discount_configuration &&
      discount_level == o.discount_level &&
      dispatch_notification == o.dispatch_notification &&
      dispatch_notification_item == o.dispatch_notification_item &&
      economic_zone == o.economic_zone &&
      end_of_day_statement == o.end_of_day_statement &&
      entry_gate == o.entry_gate &&
      event == o.event &&
      external_system_call == o.external_system_call &&
      fiscal_unit == o.fiscal_unit &&
      image == o.image &&
      info_text == o.info_text &&
      inventory == o.inventory &&
      inventory_list == o.inventory_list &&
      inventory_list_item == o.inventory_list_item &&
      item_sequence == o.item_sequence &&
      language == o.language &&
      loyalty_card == o.loyalty_card &&
      number_range_configuration == o.number_range_configuration &&
      order_portal_supplier == o.order_portal_supplier &&
      organizational_unit == o.organizational_unit &&
      payment_method == o.payment_method &&
      payment_method_category == o.payment_method_category &&
      pos == o.pos &&
      pos_balance == o.pos_balance &&
      pos_button_layout == o.pos_button_layout &&
      pos_page_layout_configuration == o.pos_page_layout_configuration &&
      pos_profile == o.pos_profile &&
      price == o.price &&
      price_group == o.price_group &&
      price_rule == o.price_rule &&
      product == o.product &&
      production_type == o.production_type &&
      promotion == o.promotion &&
      receipt == o.receipt &&
      receipt_layout_configuration == o.receipt_layout_configuration &&
      report_file == o.report_file &&
       == o. &&
      sales_tax == o.sales_tax &&
      sector == o.sector &&
      special_price_configuration == o.special_price_configuration &&
      stock_adjustment == o.stock_adjustment &&
      stock_adjustment_item == o.stock_adjustment_item &&
      stock_order == o.stock_order &&
      stock_order_item == o.stock_order_item &&
      stock_receipt == o.stock_receipt &&
      stock_receipt_item == o.stock_receipt_item &&
      supplier == o.supplier &&
      tag == o.tag &&
      ticket_definition == o.ticket_definition &&
      time_tracking_entity == o.time_tracking_entity &&
      time_tracking_entry == o.time_tracking_entry &&
      user == o.user &&
      user_role == o.user_role &&
      voucher == o.voucher &&
      voucher_configuration == o.voucher_configuration &&
      voucher_transaction == o.voucher_transaction
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



873
874
875
876
877
878
879
880
881
882
883
884
885
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 873

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


765
766
767
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 765

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



771
772
773
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 771

def hash
  [, additional_receipt_info_type, assortment, attendance, cashier, cashier_role, cashier_verification_requirement, commodity_group, , cost_center, coupon, currency, customer, customer_display_configuration, customer_group, customer_order, data_exchange_configuration, delivery_note, device_configuration_variable, discount_configuration, discount_level, dispatch_notification, dispatch_notification_item, economic_zone, end_of_day_statement, entry_gate, event, external_system_call, fiscal_unit, image, info_text, inventory, inventory_list, inventory_list_item, item_sequence, language, loyalty_card, number_range_configuration, order_portal_supplier, organizational_unit, payment_method, payment_method_category, pos, pos_balance, pos_button_layout, pos_page_layout_configuration, pos_profile, price, price_group, price_rule, product, production_type, promotion, receipt, receipt_layout_configuration, report_file, , sales_tax, sector, special_price_configuration, stock_adjustment, stock_adjustment_item, stock_order, stock_order_item, stock_receipt, stock_receipt_item, supplier, tag, ticket_definition, time_tracking_entity, time_tracking_entry, user, user_role, voucher, voucher_configuration, voucher_transaction].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



667
668
669
670
671
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 667

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



849
850
851
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 849

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



855
856
857
858
859
860
861
862
863
864
865
866
867
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 855

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



843
844
845
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 843

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



675
676
677
678
# File 'lib/korona-cloud-client/models/account_max_revisions.rb', line 675

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end