Class: KoronaCloudClient::DeliveryNote
- Inherits:
-
Object
- Object
- KoronaCloudClient::DeliveryNote
- Defined in:
- lib/korona-cloud-client/models/delivery_note.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
indicates whether the object is active for use or not.
-
#booking_time ⇒ Object
yyyy-MM-dd’T’HH:mm:ssXXX.
-
#cashier ⇒ Object
Returns the value of attribute cashier.
-
#comment ⇒ Object
Returns the value of attribute comment.
-
#customer ⇒ Object
Returns the value of attribute customer.
-
#customer_order ⇒ Object
Returns the value of attribute customer_order.
-
#delivery_time ⇒ Object
yyyy-MM-dd’T’HH:mm:ssXXX.
-
#finalized ⇒ Object
Returns the value of attribute finalized.
-
#finish_time ⇒ Object
yyyy-MM-dd’T’HH:mm:ssXXX.
-
#id ⇒ Object
global object uuid (xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx).
-
#items ⇒ Object
Returns the value of attribute items.
-
#number ⇒ Object
number of the object, like it is set in backoffice.
-
#order_number ⇒ Object
Returns the value of attribute order_number.
-
#organizational_unit ⇒ Object
Returns the value of attribute organizational_unit.
-
#point_of_sale ⇒ Object
Returns the value of attribute point_of_sale.
-
#revision ⇒ Object
the revision number of the object.
-
#signature ⇒ Object
Returns the value of attribute signature.
-
#total ⇒ Object
Returns the value of attribute total.
-
#warehouse ⇒ Object
Returns the value of attribute warehouse.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeliveryNote
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DeliveryNote
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KoronaCloudClient::DeliveryNote` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KoronaCloudClient::DeliveryNote`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'revision') self.revision = attributes[:'revision'] end if attributes.key?(:'number') self.number = attributes[:'number'] end if attributes.key?(:'booking_time') self.booking_time = attributes[:'booking_time'] end if attributes.key?(:'cashier') self.cashier = attributes[:'cashier'] end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'customer') self.customer = attributes[:'customer'] end if attributes.key?(:'order_number') self.order_number = attributes[:'order_number'] end if attributes.key?(:'organizational_unit') self.organizational_unit = attributes[:'organizational_unit'] end if attributes.key?(:'warehouse') self.warehouse = attributes[:'warehouse'] end if attributes.key?(:'point_of_sale') self.point_of_sale = attributes[:'point_of_sale'] end if attributes.key?(:'total') self.total = attributes[:'total'] end if attributes.key?(:'finish_time') self.finish_time = attributes[:'finish_time'] end if attributes.key?(:'delivery_time') self.delivery_time = attributes[:'delivery_time'] end if attributes.key?(:'finalized') self.finalized = attributes[:'finalized'] end if attributes.key?(:'items') if (value = attributes[:'items']).is_a?(Array) self.items = value end end if attributes.key?(:'signature') self.signature = attributes[:'signature'] end if attributes.key?(:'customer_order') self.customer_order = attributes[:'customer_order'] end end |
Instance Attribute Details
#active ⇒ Object
indicates whether the object is active for use or not
19 20 21 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 19 def active @active end |
#booking_time ⇒ Object
yyyy-MM-dd’T’HH:mm:ssXXX
31 32 33 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 31 def booking_time @booking_time end |
#cashier ⇒ Object
Returns the value of attribute cashier.
33 34 35 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 33 def cashier @cashier end |
#comment ⇒ Object
Returns the value of attribute comment.
35 36 37 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 35 def comment @comment end |
#customer ⇒ Object
Returns the value of attribute customer.
37 38 39 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 37 def customer @customer end |
#customer_order ⇒ Object
Returns the value of attribute customer_order.
61 62 63 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 61 def customer_order @customer_order end |
#delivery_time ⇒ Object
yyyy-MM-dd’T’HH:mm:ssXXX
53 54 55 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 53 def delivery_time @delivery_time end |
#finalized ⇒ Object
Returns the value of attribute finalized.
55 56 57 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 55 def finalized @finalized end |
#finish_time ⇒ Object
yyyy-MM-dd’T’HH:mm:ssXXX
50 51 52 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 50 def finish_time @finish_time end |
#id ⇒ Object
global object uuid (xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx)
22 23 24 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 22 def id @id end |
#items ⇒ Object
Returns the value of attribute items.
57 58 59 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 57 def items @items end |
#number ⇒ Object
number of the object, like it is set in backoffice
28 29 30 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 28 def number @number end |
#order_number ⇒ Object
Returns the value of attribute order_number.
39 40 41 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 39 def order_number @order_number end |
#organizational_unit ⇒ Object
Returns the value of attribute organizational_unit.
41 42 43 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 41 def organizational_unit @organizational_unit end |
#point_of_sale ⇒ Object
Returns the value of attribute point_of_sale.
45 46 47 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 45 def point_of_sale @point_of_sale end |
#revision ⇒ Object
the revision number of the object. revision numbers are unique per object-type. there is is no object of the same type with identical revision numbers.
25 26 27 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 25 def revision @revision end |
#signature ⇒ Object
Returns the value of attribute signature.
59 60 61 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 59 def signature @signature end |
#total ⇒ Object
Returns the value of attribute total.
47 48 49 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 47 def total @total end |
#warehouse ⇒ Object
Returns the value of attribute warehouse.
43 44 45 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 43 def warehouse @warehouse end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 298 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = KoronaCloudClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 89 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 64 def self.attribute_map { :'active' => :'active', :'id' => :'id', :'revision' => :'revision', :'number' => :'number', :'booking_time' => :'bookingTime', :'cashier' => :'cashier', :'comment' => :'comment', :'customer' => :'customer', :'order_number' => :'orderNumber', :'organizational_unit' => :'organizationalUnit', :'warehouse' => :'warehouse', :'point_of_sale' => :'pointOfSale', :'total' => :'total', :'finish_time' => :'finishTime', :'delivery_time' => :'deliveryTime', :'finalized' => :'finalized', :'items' => :'items', :'signature' => :'signature', :'customer_order' => :'customerOrder' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 274 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
119 120 121 122 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 119 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 94 def self.openapi_types { :'active' => :'Boolean', :'id' => :'String', :'revision' => :'Integer', :'number' => :'String', :'booking_time' => :'Time', :'cashier' => :'ModelReference', :'comment' => :'String', :'customer' => :'ModelReference', :'order_number' => :'String', :'organizational_unit' => :'ModelReference', :'warehouse' => :'ModelReference', :'point_of_sale' => :'ModelReference', :'total' => :'TotalPrice', :'finish_time' => :'Time', :'delivery_time' => :'Time', :'finalized' => :'Boolean', :'items' => :'Array<DeliveryNoteItem>', :'signature' => :'Signature', :'customer_order' => :'ModelReference' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 235 def ==(o) return true if self.equal?(o) self.class == o.class && active == o.active && id == o.id && revision == o.revision && number == o.number && booking_time == o.booking_time && cashier == o.cashier && comment == o.comment && customer == o.customer && order_number == o.order_number && organizational_unit == o.organizational_unit && warehouse == o.warehouse && point_of_sale == o.point_of_sale && total == o.total && finish_time == o.finish_time && delivery_time == o.delivery_time && finalized == o.finalized && items == o.items && signature == o.signature && customer_order == o.customer_order end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 369 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
261 262 263 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 261 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
267 268 269 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 267 def hash [active, id, revision, number, booking_time, cashier, comment, customer, order_number, organizational_unit, warehouse, point_of_sale, total, finish_time, delivery_time, finalized, items, signature, customer_order].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
220 221 222 223 224 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 220 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
345 346 347 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 345 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 351 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
339 340 341 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 339 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
228 229 230 231 |
# File 'lib/korona-cloud-client/models/delivery_note.rb', line 228 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |