Class: KoronaCloudClient::EndOfDayStatementSummary
- Inherits:
-
Object
- Object
- KoronaCloudClient::EndOfDayStatementSummary
- Defined in:
- lib/korona-cloud-client/models/end_of_day_statement_summary.rb
Instance Attribute Summary collapse
-
#accounts ⇒ Object
Returns the value of attribute accounts.
-
#cashiers ⇒ Object
Returns the value of attribute cashiers.
-
#commodity_groups ⇒ Object
Returns the value of attribute commodity_groups.
-
#customer_groups ⇒ Object
Returns the value of attribute customer_groups.
-
#payments ⇒ Object
Returns the value of attribute payments.
-
#taxes ⇒ Object
Returns the value of attribute taxes.
-
#vouchers ⇒ Object
Returns the value of attribute vouchers.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EndOfDayStatementSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EndOfDayStatementSummary
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KoronaCloudClient::EndOfDayStatementSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KoronaCloudClient::EndOfDayStatementSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'accounts') if (value = attributes[:'accounts']).is_a?(Array) self.accounts = value end end if attributes.key?(:'cashiers') if (value = attributes[:'cashiers']).is_a?(Array) self.cashiers = value end end if attributes.key?(:'commodity_groups') if (value = attributes[:'commodity_groups']).is_a?(Array) self.commodity_groups = value end end if attributes.key?(:'customer_groups') if (value = attributes[:'customer_groups']).is_a?(Array) self.customer_groups = value end end if attributes.key?(:'payments') if (value = attributes[:'payments']).is_a?(Array) self.payments = value end end if attributes.key?(:'taxes') if (value = attributes[:'taxes']).is_a?(Array) self.taxes = value end end if attributes.key?(:'vouchers') if (value = attributes[:'vouchers']).is_a?(Array) self.vouchers = value end end end |
Instance Attribute Details
#accounts ⇒ Object
Returns the value of attribute accounts.
18 19 20 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 18 def accounts @accounts end |
#cashiers ⇒ Object
Returns the value of attribute cashiers.
20 21 22 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 20 def cashiers @cashiers end |
#commodity_groups ⇒ Object
Returns the value of attribute commodity_groups.
22 23 24 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 22 def commodity_groups @commodity_groups end |
#customer_groups ⇒ Object
Returns the value of attribute customer_groups.
24 25 26 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 24 def customer_groups @customer_groups end |
#payments ⇒ Object
Returns the value of attribute payments.
26 27 28 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 26 def payments @payments end |
#taxes ⇒ Object
Returns the value of attribute taxes.
28 29 30 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 28 def taxes @taxes end |
#vouchers ⇒ Object
Returns the value of attribute vouchers.
30 31 32 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 30 def vouchers @vouchers end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 265 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = KoronaCloudClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 46 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 33 def self.attribute_map { :'accounts' => :'accounts', :'cashiers' => :'cashiers', :'commodity_groups' => :'commodityGroups', :'customer_groups' => :'customerGroups', :'payments' => :'payments', :'taxes' => :'taxes', :'vouchers' => :'vouchers' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 241 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 51 def self.openapi_types { :'accounts' => :'Array<AccountSummary>', :'cashiers' => :'Array<CashierSummary>', :'commodity_groups' => :'Array<CommodityGroupSummary>', :'customer_groups' => :'Array<CustomerGroupSummary>', :'payments' => :'Array<PaymentSummary>', :'taxes' => :'Array<TaxSummary>', :'vouchers' => :'Array<VoucherSummary>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 214 def ==(o) return true if self.equal?(o) self.class == o.class && accounts == o.accounts && cashiers == o.cashiers && commodity_groups == o.commodity_groups && customer_groups == o.customer_groups && payments == o.payments && taxes == o.taxes && vouchers == o.vouchers end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 336 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
228 229 230 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 228 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
234 235 236 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 234 def hash [accounts, cashiers, commodity_groups, customer_groups, payments, taxes, vouchers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
312 313 314 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 312 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 318 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
306 307 308 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 306 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 |
# File 'lib/korona-cloud-client/models/end_of_day_statement_summary.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |