Class: KoronaCloudClient::ExternalForm
- Inherits:
-
Object
- Object
- KoronaCloudClient::ExternalForm
- Defined in:
- lib/korona-cloud-client/models/external_form.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#active ⇒ Object
indicates whether the object is active for use or not.
-
#category ⇒ Object
Returns the value of attribute category.
-
#display_url ⇒ Object
Returns the value of attribute display_url.
-
#id ⇒ Object
global object uuid (xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx).
-
#name ⇒ Object
Returns the value of attribute name.
-
#number ⇒ Object
number of the object, like it is set in backoffice.
-
#revision ⇒ Object
the revision number of the object.
-
#user_roles ⇒ Object
Returns the value of attribute user_roles.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExternalForm
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ExternalForm
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KoronaCloudClient::ExternalForm` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KoronaCloudClient::ExternalForm`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'revision') self.revision = attributes[:'revision'] end if attributes.key?(:'number') self.number = attributes[:'number'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'display_url') self.display_url = attributes[:'display_url'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'user_roles') if (value = attributes[:'user_roles']).is_a?(Array) self.user_roles = value end end end |
Instance Attribute Details
#active ⇒ Object
indicates whether the object is active for use or not
19 20 21 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 19 def active @active end |
#category ⇒ Object
Returns the value of attribute category.
34 35 36 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 34 def category @category end |
#display_url ⇒ Object
Returns the value of attribute display_url.
32 33 34 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 32 def display_url @display_url end |
#id ⇒ Object
global object uuid (xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx)
22 23 24 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 22 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
30 31 32 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 30 def name @name end |
#number ⇒ Object
number of the object, like it is set in backoffice
28 29 30 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 28 def number @number end |
#revision ⇒ Object
the revision number of the object. revision numbers are unique per object-type. there is is no object of the same type with identical revision numbers.
25 26 27 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 25 def revision @revision end |
#user_roles ⇒ Object
Returns the value of attribute user_roles.
36 37 38 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 36 def user_roles @user_roles end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 244 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = KoronaCloudClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 75 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 61 def self.attribute_map { :'active' => :'active', :'id' => :'id', :'revision' => :'revision', :'number' => :'number', :'name' => :'name', :'display_url' => :'displayUrl', :'category' => :'category', :'user_roles' => :'userRoles' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 220 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 94 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 80 def self.openapi_types { :'active' => :'Boolean', :'id' => :'String', :'revision' => :'Integer', :'number' => :'String', :'name' => :'String', :'display_url' => :'String', :'category' => :'String', :'user_roles' => :'Array<ModelReference>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 192 def ==(o) return true if self.equal?(o) self.class == o.class && active == o.active && id == o.id && revision == o.revision && number == o.number && name == o.name && display_url == o.display_url && category == o.category && user_roles == o.user_roles end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 315 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 213 def hash [active, id, revision, number, name, display_url, category, user_roles].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
291 292 293 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 291 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 297 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
285 286 287 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 285 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
159 160 161 162 163 164 |
# File 'lib/korona-cloud-client/models/external_form.rb', line 159 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' category_validator = EnumAttributeValidator.new('String', ["NAVIGATIONENTRYCATEGORY_PURCHASE", "NAVIGATIONENTRYCATEGORY_STOCKMANAGEMENT", "NAVIGATIONENTRYCATEGORY_HOSPITALITY", "NAVIGATIONENTRYCATEGORY_TICKETING", "NAVIGATIONENTRYCATEGORY_DISPOSAL", "NAVIGATIONENTRYCATEGORY_EMPLOYEES", "NAVIGATIONENTRYCATEGORY_EVALUATIONS", "NAVIGATIONENTRYCATEGORY_SETTINGS", "NAVIGATIONENTRYCATEGORY_FRANCHISE", "NAVIGATIONENTRYCATEGORY_INVOICING", "NAVIGATIONENTRYCATEGORY_PROMOTIONS"]) return false unless category_validator.valid?(@category) true end |