Class: KoronaCloudClient::KoronaAccountApi
- Inherits:
-
Object
- Object
- KoronaCloudClient::KoronaAccountApi
- Defined in:
- lib/korona-cloud-client/api/korona_account_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_account_max_revisions(korona_account_id, opts = {}) ⇒ AccountMaxRevisions
returns the max revisions of relevant types.
-
#get_account_max_revisions_with_http_info(korona_account_id, opts = {}) ⇒ Array<(AccountMaxRevisions, Integer, Hash)>
returns the max revisions of relevant types.
-
#get_elster_export_data(korona_account_id, opts = {}) ⇒ ElsterData
returns the elster export in xml formatted text for all organizational units per tax id.
-
#get_elster_export_data_with_http_info(korona_account_id, opts = {}) ⇒ Array<(ElsterData, Integer, Hash)>
returns the elster export in xml formatted text for all organizational units per tax id.
-
#get_korona_account(korona_account_id, opts = {}) ⇒ KoronaAccount
returns the single korona account.
-
#get_korona_account_with_http_info(korona_account_id, opts = {}) ⇒ Array<(KoronaAccount, Integer, Hash)>
returns the single korona account.
-
#initialize(api_client = ApiClient.default) ⇒ KoronaAccountApi
constructor
A new instance of KoronaAccountApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ KoronaAccountApi
Returns a new instance of KoronaAccountApi.
19 20 21 |
# File 'lib/korona-cloud-client/api/korona_account_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/korona-cloud-client/api/korona_account_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_account_max_revisions(korona_account_id, opts = {}) ⇒ AccountMaxRevisions
returns the max revisions of relevant types
26 27 28 29 |
# File 'lib/korona-cloud-client/api/korona_account_api.rb', line 26 def get_account_max_revisions(korona_account_id, opts = {}) data, _status_code, _headers = get_account_max_revisions_with_http_info(korona_account_id, opts) data end |
#get_account_max_revisions_with_http_info(korona_account_id, opts = {}) ⇒ Array<(AccountMaxRevisions, Integer, Hash)>
returns the max revisions of relevant types
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/korona-cloud-client/api/korona_account_api.rb', line 35 def get_account_max_revisions_with_http_info(korona_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KoronaAccountApi.get_account_max_revisions ...' end # verify the required parameter 'korona_account_id' is set if @api_client.config.client_side_validation && korona_account_id.nil? fail ArgumentError, "Missing the required parameter 'korona_account_id' when calling KoronaAccountApi.get_account_max_revisions" end # resource path local_var_path = '/accounts/{koronaAccountId}/maxRevisions'.sub('{' + 'koronaAccountId' + '}', CGI.escape(korona_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AccountMaxRevisions' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"KoronaAccountApi.get_account_max_revisions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KoronaAccountApi#get_account_max_revisions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_elster_export_data(korona_account_id, opts = {}) ⇒ ElsterData
returns the elster export in xml formatted text for all organizational units per tax id
87 88 89 90 |
# File 'lib/korona-cloud-client/api/korona_account_api.rb', line 87 def get_elster_export_data(korona_account_id, opts = {}) data, _status_code, _headers = get_elster_export_data_with_http_info(korona_account_id, opts) data end |
#get_elster_export_data_with_http_info(korona_account_id, opts = {}) ⇒ Array<(ElsterData, Integer, Hash)>
returns the elster export in xml formatted text for all organizational units per tax id
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/korona-cloud-client/api/korona_account_api.rb', line 96 def get_elster_export_data_with_http_info(korona_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KoronaAccountApi.get_elster_export_data ...' end # verify the required parameter 'korona_account_id' is set if @api_client.config.client_side_validation && korona_account_id.nil? fail ArgumentError, "Missing the required parameter 'korona_account_id' when calling KoronaAccountApi.get_elster_export_data" end # resource path local_var_path = '/accounts/{koronaAccountId}/elsterExport'.sub('{' + 'koronaAccountId' + '}', CGI.escape(korona_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ElsterData' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"KoronaAccountApi.get_elster_export_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KoronaAccountApi#get_elster_export_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_korona_account(korona_account_id, opts = {}) ⇒ KoronaAccount
returns the single korona account
148 149 150 151 |
# File 'lib/korona-cloud-client/api/korona_account_api.rb', line 148 def get_korona_account(korona_account_id, opts = {}) data, _status_code, _headers = get_korona_account_with_http_info(korona_account_id, opts) data end |
#get_korona_account_with_http_info(korona_account_id, opts = {}) ⇒ Array<(KoronaAccount, Integer, Hash)>
returns the single korona account
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/korona-cloud-client/api/korona_account_api.rb', line 157 def get_korona_account_with_http_info(korona_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KoronaAccountApi.get_korona_account ...' end # verify the required parameter 'korona_account_id' is set if @api_client.config.client_side_validation && korona_account_id.nil? fail ArgumentError, "Missing the required parameter 'korona_account_id' when calling KoronaAccountApi.get_korona_account" end # resource path local_var_path = '/accounts/{koronaAccountId}'.sub('{' + 'koronaAccountId' + '}', CGI.escape(korona_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'KoronaAccount' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"KoronaAccountApi.get_korona_account", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KoronaAccountApi#get_korona_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |