Class: KoronaCloudClient::OrganizationalUnit

Inherits:
Object
  • Object
show all
Defined in:
lib/korona-cloud-client/models/organizational_unit.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OrganizationalUnit

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KoronaCloudClient::OrganizationalUnit` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KoronaCloudClient::OrganizationalUnit`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'revision')
    self.revision = attributes[:'revision']
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'cost_center')
    self.cost_center = attributes[:'cost_center']
  end

  if attributes.key?(:'economic_zone')
    self.economic_zone = attributes[:'economic_zone']
  end

  if attributes.key?(:'eh_number')
    self.eh_number = attributes[:'eh_number']
  end

  if attributes.key?(:'identification')
    self.identification = attributes[:'identification']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'opening_hours')
    if (value = attributes[:'opening_hours']).is_a?(Array)
      self.opening_hours = value
    end
  end

  if attributes.key?(:'parent_organizational_unit')
    self.parent_organizational_unit = attributes[:'parent_organizational_unit']
  end

  if attributes.key?(:'price_group')
    self.price_group = attributes[:'price_group']
  end

  if attributes.key?(:'warehouse')
    self.warehouse = attributes[:'warehouse']
  end

  if attributes.key?(:'org_from_order')
    self.org_from_order = attributes[:'org_from_order']
  end

  if attributes.key?(:'receipt_share_enabled')
    self.receipt_share_enabled = attributes[:'receipt_share_enabled']
  end

  if attributes.key?(:'valid_alternative_pos_profiles')
    if (value = attributes[:'valid_alternative_pos_profiles']).is_a?(Array)
      self.valid_alternative_pos_profiles = value
    end
  end

  if attributes.key?(:'alternative_price_group')
    self.alternative_price_group = attributes[:'alternative_price_group']
  end

  if attributes.key?(:'bank_information')
    self.bank_information = attributes[:'bank_information']
  end

  if attributes.key?(:'tax_office_number')
    self.tax_office_number = attributes[:'tax_office_number']
  end
end

Instance Attribute Details

#activeObject

indicates whether the object is active for use or not



19
20
21
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 19

def active
  @active
end

#addressObject

Returns the value of attribute address.



30
31
32
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 30

def address
  @address
end

#alternative_price_groupObject

Returns the value of attribute alternative_price_group.



56
57
58
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 56

def alternative_price_group
  @alternative_price_group
end

#bank_informationObject

Returns the value of attribute bank_information.



58
59
60
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 58

def bank_information
  @bank_information
end

#cost_centerObject

Returns the value of attribute cost_center.



32
33
34
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 32

def cost_center
  @cost_center
end

#economic_zoneObject

Returns the value of attribute economic_zone.



34
35
36
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 34

def economic_zone
  @economic_zone
end

#eh_numberObject

Returns the value of attribute eh_number.



36
37
38
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 36

def eh_number
  @eh_number
end

#idObject

global object uuid (xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx)



22
23
24
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 22

def id
  @id
end

#identificationObject

Returns the value of attribute identification.



38
39
40
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 38

def identification
  @identification
end

#nameObject

Returns the value of attribute name.



40
41
42
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 40

def name
  @name
end

#numberObject

number of the object, like it is set in backoffice



28
29
30
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 28

def number
  @number
end

#opening_hoursObject

Returns the value of attribute opening_hours.



42
43
44
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 42

def opening_hours
  @opening_hours
end

#org_from_orderObject

Returns the value of attribute org_from_order.



50
51
52
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 50

def org_from_order
  @org_from_order
end

#parent_organizational_unitObject

Returns the value of attribute parent_organizational_unit.



44
45
46
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 44

def parent_organizational_unit
  @parent_organizational_unit
end

#price_groupObject

Returns the value of attribute price_group.



46
47
48
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 46

def price_group
  @price_group
end

#receipt_share_enabledObject

Returns the value of attribute receipt_share_enabled.



52
53
54
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 52

def receipt_share_enabled
  @receipt_share_enabled
end

#revisionObject

the revision number of the object. revision numbers are unique per object-type. there is is no object of the same type with identical revision numbers.



25
26
27
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 25

def revision
  @revision
end

#tax_office_numberObject

Returns the value of attribute tax_office_number.



60
61
62
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 60

def tax_office_number
  @tax_office_number
end

#valid_alternative_pos_profilesObject

Returns the value of attribute valid_alternative_pos_profiles.



54
55
56
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 54

def valid_alternative_pos_profiles
  @valid_alternative_pos_profiles
end

#warehouseObject

Returns the value of attribute warehouse.



48
49
50
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 48

def warehouse
  @warehouse
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 333

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KoronaCloudClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 63

def self.attribute_map
  {
    :'active' => :'active',
    :'id' => :'id',
    :'revision' => :'revision',
    :'number' => :'number',
    :'address' => :'address',
    :'cost_center' => :'costCenter',
    :'economic_zone' => :'economicZone',
    :'eh_number' => :'ehNumber',
    :'identification' => :'identification',
    :'name' => :'name',
    :'opening_hours' => :'openingHours',
    :'parent_organizational_unit' => :'parentOrganizationalUnit',
    :'price_group' => :'priceGroup',
    :'warehouse' => :'warehouse',
    :'org_from_order' => :'orgFromOrder',
    :'receipt_share_enabled' => :'receiptShareEnabled',
    :'valid_alternative_pos_profiles' => :'validAlternativePosProfiles',
    :'alternative_price_group' => :'alternativePriceGroup',
    :'bank_information' => :'bankInformation',
    :'tax_office_number' => :'taxOfficeNumber'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 309

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 94

def self.openapi_types
  {
    :'active' => :'Boolean',
    :'id' => :'String',
    :'revision' => :'Integer',
    :'number' => :'String',
    :'address' => :'AddressInformation',
    :'cost_center' => :'ModelReference',
    :'economic_zone' => :'ModelReference',
    :'eh_number' => :'Integer',
    :'identification' => :'CompanyIdentification',
    :'name' => :'String',
    :'opening_hours' => :'Array<OpeningHours>',
    :'parent_organizational_unit' => :'ModelReference',
    :'price_group' => :'ModelReference',
    :'warehouse' => :'Boolean',
    :'org_from_order' => :'Boolean',
    :'receipt_share_enabled' => :'Boolean',
    :'valid_alternative_pos_profiles' => :'Array<ModelReference>',
    :'alternative_price_group' => :'ModelReference',
    :'bank_information' => :'BankInformation',
    :'tax_office_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 269

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active == o.active &&
      id == o.id &&
      revision == o.revision &&
      number == o.number &&
      address == o.address &&
      cost_center == o.cost_center &&
      economic_zone == o.economic_zone &&
      eh_number == o.eh_number &&
      identification == o.identification &&
      name == o.name &&
      opening_hours == o.opening_hours &&
      parent_organizational_unit == o.parent_organizational_unit &&
      price_group == o.price_group &&
      warehouse == o.warehouse &&
      org_from_order == o.org_from_order &&
      receipt_share_enabled == o.receipt_share_enabled &&
      valid_alternative_pos_profiles == o.valid_alternative_pos_profiles &&
      alternative_price_group == o.alternative_price_group &&
      bank_information == o.bank_information &&
      tax_office_number == o.tax_office_number
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 404

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


296
297
298
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 296

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



302
303
304
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 302

def hash
  [active, id, revision, number, address, cost_center, economic_zone, eh_number, identification, name, opening_hours, parent_organizational_unit, price_group, warehouse, org_from_order, receipt_share_enabled, valid_alternative_pos_profiles, alternative_price_group, bank_information, tax_office_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
234
235
236
237
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 229

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



380
381
382
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 380

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 386

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



374
375
376
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 374

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



241
242
243
244
245
# File 'lib/korona-cloud-client/models/organizational_unit.rb', line 241

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end