Class: KoronaCloudClient::Payment
- Inherits:
-
Object
- Object
- KoronaCloudClient::Payment
- Defined in:
- lib/korona-cloud-client/models/payment.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Returns the value of attribute amount.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#external_references ⇒ Object
Returns the value of attribute external_references.
-
#input_amount ⇒ Object
Returns the value of attribute input_amount.
-
#payment_method ⇒ Object
Returns the value of attribute payment_method.
-
#payment_terminal_receipts ⇒ Object
Returns the value of attribute payment_terminal_receipts.
-
#prepaid_card ⇒ Object
Returns the value of attribute prepaid_card.
-
#process_data ⇒ Object
Returns the value of attribute process_data.
-
#ref_data ⇒ Object
Returns the value of attribute ref_data.
-
#ref_number ⇒ Object
Returns the value of attribute ref_number.
-
#slip_number ⇒ Object
Returns the value of attribute slip_number.
-
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
-
#transaction_time ⇒ Object
yyyy-MM-dd’T’HH:mm:ssXXX.
-
#transaction_token ⇒ Object
Returns the value of attribute transaction_token.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Payment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Payment
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/korona-cloud-client/models/payment.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KoronaCloudClient::Payment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KoronaCloudClient::Payment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'payment_method') self.payment_method = attributes[:'payment_method'] end if attributes.key?(:'transaction_time') self.transaction_time = attributes[:'transaction_time'] end if attributes.key?(:'transaction_token') self.transaction_token = attributes[:'transaction_token'] end if attributes.key?(:'external_references') if (value = attributes[:'external_references']).is_a?(Hash) self.external_references = value end end if attributes.key?(:'payment_terminal_receipts') if (value = attributes[:'payment_terminal_receipts']).is_a?(Array) self.payment_terminal_receipts = value end end if attributes.key?(:'prepaid_card') self.prepaid_card = attributes[:'prepaid_card'] end if attributes.key?(:'input_amount') self.input_amount = attributes[:'input_amount'] end if attributes.key?(:'transaction_id') self.transaction_id = attributes[:'transaction_id'] end if attributes.key?(:'process_data') self.process_data = attributes[:'process_data'] end if attributes.key?(:'ref_data') self.ref_data = attributes[:'ref_data'] end if attributes.key?(:'ref_number') self.ref_number = attributes[:'ref_number'] end if attributes.key?(:'slip_number') self.slip_number = attributes[:'slip_number'] end end |
Instance Attribute Details
#amount ⇒ Object
Returns the value of attribute amount.
18 19 20 |
# File 'lib/korona-cloud-client/models/payment.rb', line 18 def amount @amount end |
#currency ⇒ Object
Returns the value of attribute currency.
20 21 22 |
# File 'lib/korona-cloud-client/models/payment.rb', line 20 def currency @currency end |
#external_references ⇒ Object
Returns the value of attribute external_references.
29 30 31 |
# File 'lib/korona-cloud-client/models/payment.rb', line 29 def external_references @external_references end |
#input_amount ⇒ Object
Returns the value of attribute input_amount.
35 36 37 |
# File 'lib/korona-cloud-client/models/payment.rb', line 35 def input_amount @input_amount end |
#payment_method ⇒ Object
Returns the value of attribute payment_method.
22 23 24 |
# File 'lib/korona-cloud-client/models/payment.rb', line 22 def payment_method @payment_method end |
#payment_terminal_receipts ⇒ Object
Returns the value of attribute payment_terminal_receipts.
31 32 33 |
# File 'lib/korona-cloud-client/models/payment.rb', line 31 def payment_terminal_receipts @payment_terminal_receipts end |
#prepaid_card ⇒ Object
Returns the value of attribute prepaid_card.
33 34 35 |
# File 'lib/korona-cloud-client/models/payment.rb', line 33 def prepaid_card @prepaid_card end |
#process_data ⇒ Object
Returns the value of attribute process_data.
39 40 41 |
# File 'lib/korona-cloud-client/models/payment.rb', line 39 def process_data @process_data end |
#ref_data ⇒ Object
Returns the value of attribute ref_data.
41 42 43 |
# File 'lib/korona-cloud-client/models/payment.rb', line 41 def ref_data @ref_data end |
#ref_number ⇒ Object
Returns the value of attribute ref_number.
43 44 45 |
# File 'lib/korona-cloud-client/models/payment.rb', line 43 def ref_number @ref_number end |
#slip_number ⇒ Object
Returns the value of attribute slip_number.
45 46 47 |
# File 'lib/korona-cloud-client/models/payment.rb', line 45 def slip_number @slip_number end |
#transaction_id ⇒ Object
Returns the value of attribute transaction_id.
37 38 39 |
# File 'lib/korona-cloud-client/models/payment.rb', line 37 def transaction_id @transaction_id end |
#transaction_time ⇒ Object
yyyy-MM-dd’T’HH:mm:ssXXX
25 26 27 |
# File 'lib/korona-cloud-client/models/payment.rb', line 25 def transaction_time @transaction_time end |
#transaction_token ⇒ Object
Returns the value of attribute transaction_token.
27 28 29 |
# File 'lib/korona-cloud-client/models/payment.rb', line 27 def transaction_token @transaction_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/korona-cloud-client/models/payment.rb', line 249 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = KoronaCloudClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/korona-cloud-client/models/payment.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/korona-cloud-client/models/payment.rb', line 48 def self.attribute_map { :'amount' => :'amount', :'currency' => :'currency', :'payment_method' => :'paymentMethod', :'transaction_time' => :'transactionTime', :'transaction_token' => :'transactionToken', :'external_references' => :'externalReferences', :'payment_terminal_receipts' => :'paymentTerminalReceipts', :'prepaid_card' => :'prepaidCard', :'input_amount' => :'inputAmount', :'transaction_id' => :'transactionId', :'process_data' => :'processData', :'ref_data' => :'refData', :'ref_number' => :'refNumber', :'slip_number' => :'slipNumber' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/korona-cloud-client/models/payment.rb', line 225 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/korona-cloud-client/models/payment.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/korona-cloud-client/models/payment.rb', line 73 def self.openapi_types { :'amount' => :'Float', :'currency' => :'ModelReference', :'payment_method' => :'ModelReference', :'transaction_time' => :'Time', :'transaction_token' => :'String', :'external_references' => :'Hash<String, String>', :'payment_terminal_receipts' => :'Array<PaymentTerminalReceipt>', :'prepaid_card' => :'PrepaidCard', :'input_amount' => :'Float', :'transaction_id' => :'String', :'process_data' => :'String', :'ref_data' => :'String', :'ref_number' => :'String', :'slip_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/korona-cloud-client/models/payment.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && currency == o.currency && payment_method == o.payment_method && transaction_time == o.transaction_time && transaction_token == o.transaction_token && external_references == o.external_references && payment_terminal_receipts == o.payment_terminal_receipts && prepaid_card == o.prepaid_card && input_amount == o.input_amount && transaction_id == o.transaction_id && process_data == o.process_data && ref_data == o.ref_data && ref_number == o.ref_number && slip_number == o.slip_number end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/korona-cloud-client/models/payment.rb', line 320 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/korona-cloud-client/models/payment.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/korona-cloud-client/models/payment.rb', line 218 def hash [amount, currency, payment_method, transaction_time, transaction_token, external_references, payment_terminal_receipts, prepaid_card, input_amount, transaction_id, process_data, ref_data, ref_number, slip_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
176 177 178 179 180 |
# File 'lib/korona-cloud-client/models/payment.rb', line 176 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
296 297 298 |
# File 'lib/korona-cloud-client/models/payment.rb', line 296 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/korona-cloud-client/models/payment.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
290 291 292 |
# File 'lib/korona-cloud-client/models/payment.rb', line 290 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 |
# File 'lib/korona-cloud-client/models/payment.rb', line 184 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |