Class: KoronaCloudClient::PromotionValidity
- Inherits:
-
Object
- Object
- KoronaCloudClient::PromotionValidity
- Defined in:
- lib/korona-cloud-client/models/promotion_validity.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#date_interval ⇒ Object
Returns the value of attribute date_interval.
-
#days_of_month ⇒ Object
Returns the value of attribute days_of_month.
-
#days_of_week ⇒ Object
Returns the value of attribute days_of_week.
-
#org_selection_mode ⇒ Object
Returns the value of attribute org_selection_mode.
-
#organizational_units ⇒ Object
Returns the value of attribute organizational_units.
-
#pos_types ⇒ Object
Returns the value of attribute pos_types.
-
#time_of_day_interval ⇒ Object
Returns the value of attribute time_of_day_interval.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PromotionValidity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PromotionValidity
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KoronaCloudClient::PromotionValidity` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KoronaCloudClient::PromotionValidity`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date_interval') self.date_interval = attributes[:'date_interval'] end if attributes.key?(:'days_of_month') if (value = attributes[:'days_of_month']).is_a?(Array) self.days_of_month = value end end if attributes.key?(:'days_of_week') if (value = attributes[:'days_of_week']).is_a?(Array) self.days_of_week = value end end if attributes.key?(:'organizational_units') if (value = attributes[:'organizational_units']).is_a?(Array) self.organizational_units = value end end if attributes.key?(:'time_of_day_interval') self.time_of_day_interval = attributes[:'time_of_day_interval'] end if attributes.key?(:'org_selection_mode') self.org_selection_mode = attributes[:'org_selection_mode'] end if attributes.key?(:'pos_types') if (value = attributes[:'pos_types']).is_a?(Array) self.pos_types = value end end end |
Instance Attribute Details
#date_interval ⇒ Object
Returns the value of attribute date_interval.
18 19 20 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 18 def date_interval @date_interval end |
#days_of_month ⇒ Object
Returns the value of attribute days_of_month.
20 21 22 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 20 def days_of_month @days_of_month end |
#days_of_week ⇒ Object
Returns the value of attribute days_of_week.
22 23 24 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 22 def days_of_week @days_of_week end |
#org_selection_mode ⇒ Object
Returns the value of attribute org_selection_mode.
28 29 30 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 28 def org_selection_mode @org_selection_mode end |
#organizational_units ⇒ Object
Returns the value of attribute organizational_units.
24 25 26 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 24 def organizational_units @organizational_units end |
#pos_types ⇒ Object
Returns the value of attribute pos_types.
30 31 32 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 30 def pos_types @pos_types end |
#time_of_day_interval ⇒ Object
Returns the value of attribute time_of_day_interval.
26 27 28 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 26 def time_of_day_interval @time_of_day_interval end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 247 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = KoronaCloudClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 55 def self.attribute_map { :'date_interval' => :'dateInterval', :'days_of_month' => :'daysOfMonth', :'days_of_week' => :'daysOfWeek', :'organizational_units' => :'organizationalUnits', :'time_of_day_interval' => :'timeOfDayInterval', :'org_selection_mode' => :'orgSelectionMode', :'pos_types' => :'posTypes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 223 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 73 def self.openapi_types { :'date_interval' => :'DateInterval', :'days_of_month' => :'Array<Integer>', :'days_of_week' => :'Array<String>', :'organizational_units' => :'Array<ModelReference>', :'time_of_day_interval' => :'TimeOfDayInterval', :'org_selection_mode' => :'String', :'pos_types' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && date_interval == o.date_interval && days_of_month == o.days_of_month && days_of_week == o.days_of_week && organizational_units == o.organizational_units && time_of_day_interval == o.time_of_day_interval && org_selection_mode == o.org_selection_mode && pos_types == o.pos_types end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 318 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 216 def hash [date_interval, days_of_month, days_of_week, organizational_units, time_of_day_interval, org_selection_mode, pos_types].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
294 295 296 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 294 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 300 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
288 289 290 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 288 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 |
# File 'lib/korona-cloud-client/models/promotion_validity.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' org_selection_mode_validator = EnumAttributeValidator.new('String', ["INCLUDE", "EXCLUDE"]) return false unless org_selection_mode_validator.valid?(@org_selection_mode) true end |