Class: KoronaCloudClient::VoucherConfiguration

Inherits:
Object
  • Object
show all
Defined in:
lib/korona-cloud-client/models/voucher_configuration.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VoucherConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 141

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KoronaCloudClient::VoucherConfiguration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KoronaCloudClient::VoucherConfiguration`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'revision')
    self.revision = attributes[:'revision']
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'validity_period')
    self.validity_period = attributes[:'validity_period']
  end

  if attributes.key?(:'strict_validity')
    self.strict_validity = attributes[:'strict_validity']
  end

  if attributes.key?(:'sector')
    self.sector = attributes[:'sector']
  end

  if attributes.key?(:'follow_up_products')
    self.follow_up_products = attributes[:'follow_up_products']
  end

  if attributes.key?(:'single_use')
    self.single_use = attributes[:'single_use']
  end

  if attributes.key?(:'requires_serial_number')
    self.requires_serial_number = attributes[:'requires_serial_number']
  end

  if attributes.key?(:'production_type')
    self.production_type = attributes[:'production_type']
  end

  if attributes.key?(:'revenue_account')
    self. = attributes[:'revenue_account']
  end

  if attributes.key?(:'credit_amount')
    self.credit_amount = attributes[:'credit_amount']
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'discount')
    self.discount = attributes[:'discount']
  end

  if attributes.key?(:'requires_personalization')
    self.requires_personalization = attributes[:'requires_personalization']
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



50
51
52
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 50

def 
  @account
end

#activeObject

indicates whether the object is active for use or not



19
20
21
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 19

def active
  @active
end

#credit_amountObject

Returns the value of attribute credit_amount.



48
49
50
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 48

def credit_amount
  @credit_amount
end

#discountObject

Returns the value of attribute discount.



54
55
56
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 54

def discount
  @discount
end

#follow_up_productsObject

Returns the value of attribute follow_up_products.



38
39
40
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 38

def follow_up_products
  @follow_up_products
end

#idObject

global object uuid (xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx)



22
23
24
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 22

def id
  @id
end

#nameObject

Returns the value of attribute name.



52
53
54
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 52

def name
  @name
end

#numberObject

number of the object, like it is set in backoffice



28
29
30
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 28

def number
  @number
end

#production_typeObject

Returns the value of attribute production_type.



44
45
46
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 44

def production_type
  @production_type
end

#requires_personalizationObject

Returns the value of attribute requires_personalization.



56
57
58
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 56

def requires_personalization
  @requires_personalization
end

#requires_serial_numberObject

Returns the value of attribute requires_serial_number.



42
43
44
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 42

def requires_serial_number
  @requires_serial_number
end

#revenue_accountObject

Returns the value of attribute revenue_account.



46
47
48
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 46

def 
  @revenue_account
end

#revisionObject

the revision number of the object. revision numbers are unique per object-type. there is is no object of the same type with identical revision numbers.



25
26
27
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 25

def revision
  @revision
end

#sectorObject

Returns the value of attribute sector.



36
37
38
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 36

def sector
  @sector
end

#single_useObject

Returns the value of attribute single_use.



40
41
42
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 40

def single_use
  @single_use
end

#strict_validityObject

Returns the value of attribute strict_validity.



34
35
36
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 34

def strict_validity
  @strict_validity
end

#typeObject

Returns the value of attribute type.



30
31
32
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 30

def type
  @type
end

#validity_periodObject

Returns the value of attribute validity_period.



32
33
34
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 32

def validity_period
  @validity_period
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 322

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KoronaCloudClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



105
106
107
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 105

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 81

def self.attribute_map
  {
    :'active' => :'active',
    :'id' => :'id',
    :'revision' => :'revision',
    :'number' => :'number',
    :'type' => :'type',
    :'validity_period' => :'validityPeriod',
    :'strict_validity' => :'strictValidity',
    :'sector' => :'sector',
    :'follow_up_products' => :'followUpProducts',
    :'single_use' => :'singleUse',
    :'requires_serial_number' => :'requiresSerialNumber',
    :'production_type' => :'productionType',
    :'revenue_account' => :'revenueAccount',
    :'credit_amount' => :'creditAmount',
    :'account' => :'account',
    :'name' => :'name',
    :'discount' => :'discount',
    :'requires_personalization' => :'requiresPersonalization'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 298

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



134
135
136
137
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 134

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 110

def self.openapi_types
  {
    :'active' => :'Boolean',
    :'id' => :'String',
    :'revision' => :'Integer',
    :'number' => :'String',
    :'type' => :'String',
    :'validity_period' => :'TimePeriod',
    :'strict_validity' => :'Boolean',
    :'sector' => :'ModelReference',
    :'follow_up_products' => :'VoucherConfigurationFollowUpProducts',
    :'single_use' => :'Boolean',
    :'requires_serial_number' => :'Boolean',
    :'production_type' => :'ModelReference',
    :'revenue_account' => :'ModelReference',
    :'credit_amount' => :'Float',
    :'account' => :'ModelReference',
    :'name' => :'String',
    :'discount' => :'VoucherConfigurationDiscountCalculation',
    :'requires_personalization' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 260

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active == o.active &&
      id == o.id &&
      revision == o.revision &&
      number == o.number &&
      type == o.type &&
      validity_period == o.validity_period &&
      strict_validity == o.strict_validity &&
      sector == o.sector &&
      follow_up_products == o.follow_up_products &&
      single_use == o.single_use &&
      requires_serial_number == o.requires_serial_number &&
      production_type == o.production_type &&
       == o. &&
      credit_amount == o.credit_amount &&
       == o. &&
      name == o.name &&
      discount == o.discount &&
      requires_personalization == o.requires_personalization
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 393

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


285
286
287
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 285

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



291
292
293
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 291

def hash
  [active, id, revision, number, type, validity_period, strict_validity, sector, follow_up_products, single_use, requires_serial_number, production_type, , credit_amount, , name, discount, requires_personalization].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 229

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



369
370
371
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 369

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 375

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



363
364
365
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 363

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



237
238
239
240
241
242
# File 'lib/korona-cloud-client/models/voucher_configuration.rb', line 237

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["DEPOSIT", "GOODS", "VALUE"])
  return false unless type_validator.valid?(@type)
  true
end