Class: KoronaCloudClient::StatisticsApi
- Inherits:
-
Object
- Object
- KoronaCloudClient::StatisticsApi
- Defined in:
- lib/korona-cloud-client/api/statistics_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_financial_accounting_data(korona_account_id, opts = {}) ⇒ StatisticListFinancialAccountingData
returns the financial accounting data by revision or date; if both is set, date will be ignored.
-
#get_financial_accounting_data_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticListFinancialAccountingData, Integer, Hash)>
returns the financial accounting data by revision or date; if both is set, date will be ignored.
-
#get_revenue(korona_account_id, opts = {}) ⇒ StatisticRevenueData
returns information about the revenue in the given period.
-
#get_revenue_for_customer_groups(korona_account_id, opts = {}) ⇒ StatisticMapStringRevenueData
returns the turnover per customer group during the given period.
-
#get_revenue_for_customer_groups_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticMapStringRevenueData, Integer, Hash)>
returns the turnover per customer group during the given period.
-
#get_revenue_hourly(korona_account_id, opts = {}) ⇒ StatisticMapStringRevenueData
returns the turnover per hour during the given period.
-
#get_revenue_hourly_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticMapStringRevenueData, Integer, Hash)>
returns the turnover per hour during the given period.
-
#get_revenue_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticRevenueData, Integer, Hash)>
returns information about the revenue in the given period.
-
#get_sector_revenue_by_month(korona_account_id, min_create_time, max_create_time, opts = {}) ⇒ StatisticListSectorData
returns revenue grouped by sector, org, and month.
-
#get_sector_revenue_by_month_with_http_info(korona_account_id, min_create_time, max_create_time, opts = {}) ⇒ Array<(StatisticListSectorData, Integer, Hash)>
returns revenue grouped by sector, org, and month.
-
#get_top_seller(korona_account_id, opts = {}) ⇒ StatisticListTopSeller
returns the top-seller.
-
#get_top_seller_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticListTopSeller, Integer, Hash)>
returns the top-seller.
-
#initialize(api_client = ApiClient.default) ⇒ StatisticsApi
constructor
A new instance of StatisticsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ StatisticsApi
Returns a new instance of StatisticsApi.
19 20 21 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_financial_accounting_data(korona_account_id, opts = {}) ⇒ StatisticListFinancialAccountingData
returns the financial accounting data by revision or date; if both is set, date will be ignored
28 29 30 31 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 28 def get_financial_accounting_data(korona_account_id, opts = {}) data, _status_code, _headers = get_financial_accounting_data_with_http_info(korona_account_id, opts) data end |
#get_financial_accounting_data_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticListFinancialAccountingData, Integer, Hash)>
returns the financial accounting data by revision or date; if both is set, date will be ignored
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 39 def get_financial_accounting_data_with_http_info(korona_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StatisticsApi.get_financial_accounting_data ...' end # verify the required parameter 'korona_account_id' is set if @api_client.config.client_side_validation && korona_account_id.nil? fail ArgumentError, "Missing the required parameter 'korona_account_id' when calling StatisticsApi.get_financial_accounting_data" end # resource path local_var_path = '/accounts/{koronaAccountId}/statistics/financialAccounting'.sub('{' + 'koronaAccountId' + '}', CGI.escape(korona_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'revision'] = opts[:'revision'] if !opts[:'revision'].nil? query_params[:'day'] = opts[:'day'] if !opts[:'day'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'StatisticListFinancialAccountingData' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"StatisticsApi.get_financial_accounting_data", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StatisticsApi#get_financial_accounting_data\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_revenue(korona_account_id, opts = {}) ⇒ StatisticRevenueData
returns information about the revenue in the given period
95 96 97 98 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 95 def get_revenue(korona_account_id, opts = {}) data, _status_code, _headers = get_revenue_with_http_info(korona_account_id, opts) data end |
#get_revenue_for_customer_groups(korona_account_id, opts = {}) ⇒ StatisticMapStringRevenueData
returns the turnover per customer group during the given period
166 167 168 169 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 166 def get_revenue_for_customer_groups(korona_account_id, opts = {}) data, _status_code, _headers = get_revenue_for_customer_groups_with_http_info(korona_account_id, opts) data end |
#get_revenue_for_customer_groups_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticMapStringRevenueData, Integer, Hash)>
returns the turnover per customer group during the given period
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 177 def get_revenue_for_customer_groups_with_http_info(korona_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StatisticsApi.get_revenue_for_customer_groups ...' end # verify the required parameter 'korona_account_id' is set if @api_client.config.client_side_validation && korona_account_id.nil? fail ArgumentError, "Missing the required parameter 'korona_account_id' when calling StatisticsApi.get_revenue_for_customer_groups" end allowable_values = ["DAY", "WEEK", "MONTH", "YEAR"] if @api_client.config.client_side_validation && opts[:'period'] && !allowable_values.include?(opts[:'period']) fail ArgumentError, "invalid value for \"period\", must be one of #{allowable_values}" end # resource path local_var_path = '/accounts/{koronaAccountId}/statistics/revenueDataForCustomerGroups'.sub('{' + 'koronaAccountId' + '}', CGI.escape(korona_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'organizationalUnit'] = opts[:'organizational_unit'] if !opts[:'organizational_unit'].nil? query_params[:'period'] = opts[:'period'] if !opts[:'period'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'StatisticMapStringRevenueData' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"StatisticsApi.get_revenue_for_customer_groups", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StatisticsApi#get_revenue_for_customer_groups\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_revenue_hourly(korona_account_id, opts = {}) ⇒ StatisticMapStringRevenueData
returns the turnover per hour during the given period
237 238 239 240 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 237 def get_revenue_hourly(korona_account_id, opts = {}) data, _status_code, _headers = get_revenue_hourly_with_http_info(korona_account_id, opts) data end |
#get_revenue_hourly_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticMapStringRevenueData, Integer, Hash)>
returns the turnover per hour during the given period
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 248 def get_revenue_hourly_with_http_info(korona_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StatisticsApi.get_revenue_hourly ...' end # verify the required parameter 'korona_account_id' is set if @api_client.config.client_side_validation && korona_account_id.nil? fail ArgumentError, "Missing the required parameter 'korona_account_id' when calling StatisticsApi.get_revenue_hourly" end allowable_values = ["DAY", "WEEK", "MONTH", "YEAR"] if @api_client.config.client_side_validation && opts[:'period'] && !allowable_values.include?(opts[:'period']) fail ArgumentError, "invalid value for \"period\", must be one of #{allowable_values}" end # resource path local_var_path = '/accounts/{koronaAccountId}/statistics/revenueDataHourly'.sub('{' + 'koronaAccountId' + '}', CGI.escape(korona_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'organizationalUnit'] = opts[:'organizational_unit'] if !opts[:'organizational_unit'].nil? query_params[:'period'] = opts[:'period'] if !opts[:'period'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'StatisticMapStringRevenueData' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"StatisticsApi.get_revenue_hourly", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StatisticsApi#get_revenue_hourly\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_revenue_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticRevenueData, Integer, Hash)>
returns information about the revenue in the given period
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 106 def get_revenue_with_http_info(korona_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StatisticsApi.get_revenue ...' end # verify the required parameter 'korona_account_id' is set if @api_client.config.client_side_validation && korona_account_id.nil? fail ArgumentError, "Missing the required parameter 'korona_account_id' when calling StatisticsApi.get_revenue" end allowable_values = ["DAY", "WEEK", "MONTH", "YEAR"] if @api_client.config.client_side_validation && opts[:'period'] && !allowable_values.include?(opts[:'period']) fail ArgumentError, "invalid value for \"period\", must be one of #{allowable_values}" end # resource path local_var_path = '/accounts/{koronaAccountId}/statistics/revenueData'.sub('{' + 'koronaAccountId' + '}', CGI.escape(korona_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'organizationalUnit'] = opts[:'organizational_unit'] if !opts[:'organizational_unit'].nil? query_params[:'period'] = opts[:'period'] if !opts[:'period'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'StatisticRevenueData' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"StatisticsApi.get_revenue", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StatisticsApi#get_revenue\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sector_revenue_by_month(korona_account_id, min_create_time, max_create_time, opts = {}) ⇒ StatisticListSectorData
returns revenue grouped by sector, org, and month
310 311 312 313 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 310 def get_sector_revenue_by_month(korona_account_id, min_create_time, max_create_time, opts = {}) data, _status_code, _headers = get_sector_revenue_by_month_with_http_info(korona_account_id, min_create_time, max_create_time, opts) data end |
#get_sector_revenue_by_month_with_http_info(korona_account_id, min_create_time, max_create_time, opts = {}) ⇒ Array<(StatisticListSectorData, Integer, Hash)>
returns revenue grouped by sector, org, and month
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 323 def get_sector_revenue_by_month_with_http_info(korona_account_id, min_create_time, max_create_time, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StatisticsApi.get_sector_revenue_by_month ...' end # verify the required parameter 'korona_account_id' is set if @api_client.config.client_side_validation && korona_account_id.nil? fail ArgumentError, "Missing the required parameter 'korona_account_id' when calling StatisticsApi.get_sector_revenue_by_month" end # verify the required parameter 'min_create_time' is set if @api_client.config.client_side_validation && min_create_time.nil? fail ArgumentError, "Missing the required parameter 'min_create_time' when calling StatisticsApi.get_sector_revenue_by_month" end # verify the required parameter 'max_create_time' is set if @api_client.config.client_side_validation && max_create_time.nil? fail ArgumentError, "Missing the required parameter 'max_create_time' when calling StatisticsApi.get_sector_revenue_by_month" end # resource path local_var_path = '/accounts/{koronaAccountId}/statistics/sectorRevenueByMonth'.sub('{' + 'koronaAccountId' + '}', CGI.escape(korona_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'minCreateTime'] = min_create_time query_params[:'maxCreateTime'] = max_create_time query_params[:'sector'] = opts[:'sector'] if !opts[:'sector'].nil? query_params[:'organizationalUnit'] = opts[:'organizational_unit'] if !opts[:'organizational_unit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'StatisticListSectorData' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"StatisticsApi.get_sector_revenue_by_month", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StatisticsApi#get_sector_revenue_by_month\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_top_seller(korona_account_id, opts = {}) ⇒ StatisticListTopSeller
returns the top-seller
390 391 392 393 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 390 def get_top_seller(korona_account_id, opts = {}) data, _status_code, _headers = get_top_seller_with_http_info(korona_account_id, opts) data end |
#get_top_seller_with_http_info(korona_account_id, opts = {}) ⇒ Array<(StatisticListTopSeller, Integer, Hash)>
returns the top-seller
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/korona-cloud-client/api/statistics_api.rb', line 402 def get_top_seller_with_http_info(korona_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StatisticsApi.get_top_seller ...' end # verify the required parameter 'korona_account_id' is set if @api_client.config.client_side_validation && korona_account_id.nil? fail ArgumentError, "Missing the required parameter 'korona_account_id' when calling StatisticsApi.get_top_seller" end allowable_values = ["DAY", "WEEK", "MONTH", "YEAR"] if @api_client.config.client_side_validation && opts[:'period'] && !allowable_values.include?(opts[:'period']) fail ArgumentError, "invalid value for \"period\", must be one of #{allowable_values}" end # resource path local_var_path = '/accounts/{koronaAccountId}/statistics/topSeller'.sub('{' + 'koronaAccountId' + '}', CGI.escape(korona_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'organizationalUnit'] = opts[:'organizational_unit'] if !opts[:'organizational_unit'].nil? query_params[:'period'] = opts[:'period'] if !opts[:'period'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'StatisticListTopSeller' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"StatisticsApi.get_top_seller", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StatisticsApi#get_top_seller\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |